Documentation
¶
Overview ¶
templ: version: v0.2.793
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DrawerToolbar ¶
func DrawerToolbar(props *ToolbarProps) templ.Component
Types ¶
type Props ¶
type Props struct {
ID string // ID to allow for identifing and targeting this Drawer.
Title string // Title
TitleID string // TitleCountID if the panel is going to show an OOB devired count
Description string // Description is the subheading or description text for the sheet.
Side Side // Side determines from which side the sheet will appear.
Toolbar *ToolbarProps // optional extra toolbar buttons
Width string // tailwind css width
XShow string // x-data value to show the dynamic header
XText string // x-text value to display as title
Class string // extra classes
ClassDetails string // extra classes applied to the detail section
}
Props defines the properties for the Drawer component.
Click to show internal directories.
Click to hide internal directories.