section

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

templ: version: v0.2.793

templ: version: v0.2.793

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Container

func Container(props *Props) templ.Component

Container will fill a parent element, and allow children to be scrollable

func Header(props *Props) templ.Component

func Scrollable

func Scrollable(props *Props) templ.Component

Scrollable will fill a parent element, preferably a Container, and allow it's children to be scrollable

Types

type Props

type Props struct {
	Title        string
	ContentLeft  templ.Component
	ContentRight []templ.Component
	Class        string
}

Jump to