Documentation
¶
Overview ¶
templ: version: v0.2.793
templ: version: v0.2.793
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Props ¶
type Props struct {
ID string // form ID
Name string // form name
Value *Item // in single mode, the value of the pre-selected item
Selected []*Item // in Mulitple Mode, the pre-selected item(s)
SelectedPlacement string // where the selected chips appears in relation to the trigger
Multiple bool // support multiple selections
By string // compare the objects by a particular property instead of by their identity
Items []*Item // slice of Items, the options to be displayed
}
Click to show internal directories.
Click to hide internal directories.